@@ -96,7 +96,7 @@ def find_blas():
 	gsl_include_paths = []
 	system_include_paths = []
 
-	sys.stdout = open(os.devnull, "w")
+	# sys.stdout = open(os.devnull, "w")
 	_try_add_from_command("numpy.distutils.system_info.get_info('mkl')['library_dirs']", candidate_paths)
 	_try_add_from_command("numpy.distutils.system_info.get_info('blas_mkl')['library_dirs']", candidate_paths)
 	_try_add_from_command("np.__config__.system_info.blas_mkl_info['library_dirs']", candidate_paths)
@@ -128,7 +128,7 @@ def find_blas():
 	_try_add_from_command("numpy.distutils.system_info.get_info('blas')['include_dirs']", gsl_include_paths)
 	_try_add_from_command("numpy.distutils.system_info.get_info('blas_opt')['include_dirs']", gsl_include_paths)
 	_try_add_from_command("scipy.__config__.blas_opt_info['include_dirs']", gsl_include_paths)
-	sys.stdout = sys.__stdout__
+	# sys.stdout = sys.__stdout__
 
 	python_fold = sys.prefix
 	system_include_paths.append(os.path.join(python_fold, "include"))
@@ -155,7 +155,9 @@ def find_blas():
 			system_include_paths.append(re.sub(r"^(.*include).*$", r"\1", fld))
 
 	_try_add_from_command("os.environ['PATH'].split(\":\")", candidate_paths)
+	_try_add_from_command("os.environ['PATH'].split(\";\")", candidate_paths)
 	_try_add_from_command("os.environ['PYTHONPATH'].split(\":\")", candidate_paths)
+	_try_add_from_command("os.environ['PYTHONPATH'].split(\";\")", candidate_paths)
 
 	paths_from_sys = [pt for pt in sys.path if bool(re.search("[Ll]ib", pt))]
 	if platform[:3] == "win":
@@ -253,6 +255,67 @@ def find_blas():
 		except:
 			pass
 
+	## Potential cases of PEP518 environments
+	paths_pep518 = []
+	for path in candidate_paths:
+		if bool(re.search(r"[Oo]verlay", path)):
+			clean_path = re.sub(r"^(.*[Oo]verlay).*$", r"\1", path)
+
+			paths_pep518.append(clean_path)
+
+			paths_pep518.append(os.path.join(clean_path, "lib"))
+			paths_pep518.append(os.path.join(clean_path, "lib", "gsl"))
+			paths_pep518.append(os.path.join(clean_path, "lib", "gsl", "lib"))
+			gsl_include_paths.append(os.path.join(clean_path, "lib", "gsl", "include"))
+			paths_pep518.append(os.path.join(clean_path, "lib", "gslcblas"))
+			paths_pep518.append(os.path.join(clean_path, "lib", "cblas"))
+			paths_pep518.append(os.path.join(clean_path, "lib", "blas"))
+			paths_pep518.append(os.path.join(clean_path, "lib", "mkl"))
+			paths_pep518.append(os.path.join(clean_path, "lib", "mkl", "lib"))
+			paths_pep518.append(os.path.join(clean_path, "lib", "mkl", "lib", "intel"))
+			mkl_include_paths.append(os.path.join(clean_path, "lib", "mkl", "include"))
+			paths_pep518.append(os.path.join(clean_path, "lib", "atlas"))
+			atlas_include_paths.append(os.path.join(clean_path, "lib", "atlas", "include"))
+			paths_pep518.append(os.path.join(clean_path, "lib", "atlas", "lib"))
+			paths_pep518.append(os.path.join(clean_path, "lib", "libatlas"))
+			atlas_include_paths.append(os.path.join(clean_path, "lib", "libatlas", "include"))
+			paths_pep518.append(os.path.join(clean_path, "lib", "libatlas", "lib"))
+
+			paths_pep518.append(os.path.join(clean_path, "Lib"))
+			paths_pep518.append(os.path.join(clean_path, "Lib", "gsl"))
+			paths_pep518.append(os.path.join(clean_path, "Lib", "gsl", "lib"))
+			gsl_include_paths.append(os.path.join(clean_path, "Lib", "gsl", "include"))
+			paths_pep518.append(os.path.join(clean_path, "Lib", "gslcblas"))
+			paths_pep518.append(os.path.join(clean_path, "Lib", "cblas"))
+			paths_pep518.append(os.path.join(clean_path, "Lib", "blas"))
+			paths_pep518.append(os.path.join(clean_path, "Lib", "mkl"))
+			paths_pep518.append(os.path.join(clean_path, "Lib", "mkl", "lib"))
+			paths_pep518.append(os.path.join(clean_path, "Lib", "mkl", "lib", "intel"))
+			mkl_include_paths.append(os.path.join(clean_path, "Lib", "mkl", "include"))
+			paths_pep518.append(os.path.join(clean_path, "Lib", "atlas"))
+			atlas_include_paths.append(os.path.join(clean_path, "Lib", "atlas", "include"))
+			paths_pep518.append(os.path.join(clean_path, "Lib", "atlas", "lib"))
+			paths_pep518.append(os.path.join(clean_path, "Lib", "libatlas"))
+			atlas_include_paths.append(os.path.join(clean_path, "Lib", "libatlas", "include"))
+			paths_pep518.append(os.path.join(clean_path, "Lib", "libatlas", "lib"))
+
+			system_include_paths.append(os.path.join(clean_path, "include"))
+			gsl_include_paths.append(os.path.join(clean_path, "include", "gsl"))
+			gsl_include_paths.append(os.path.join(clean_path, "include", "gsl", "include"))
+			gsl_include_paths.append(os.path.join(clean_path, "include", "gslcblas"))
+			system_include_paths.append(os.path.join(clean_path, "include", "cblas"))
+			system_include_paths.append(os.path.join(clean_path, "include", "blas"))
+			mkl_include_paths.append(os.path.join(clean_path, "include", "mkl"))
+			mkl_include_paths.append(os.path.join(clean_path, "include", "mkl", "lib"))
+			mkl_include_paths.append(os.path.join(clean_path, "include", "mkl", "lib", "intel"))
+			mkl_include_paths.append(os.path.join(clean_path, "include", "mkl", "include"))
+			atlas_include_paths.append(os.path.join(clean_path, "include", "atlas"))
+			atlas_include_paths.append(os.path.join(clean_path, "include", "atlas", "include"))
+			atlas_include_paths.append(os.path.join(clean_path, "include", "libatlas"))
+			atlas_include_paths.append(os.path.join(clean_path, "lib", "libatlas", "include"))
+
+	candidate_paths += paths_pep518
+
 	## Discard duplicated paths, but keep the order
 	search_paths = _deduplicate_paths(candidate_paths)
 
